@@ -13,9 +13,9 @@ except:
     data = json.load(open(dirs + '//wc_data//data.json', encoding='ansi'))
 
 
-def generator(title, length=800):
+def generator(title, lenth=800):
     body = ""
-    while len(body) < length:
+    while len(body) < lenth:
         num = random.randint(0, 100)
         if num < 10:
             body += "\r\n"
@@ -33,8 +33,8 @@ def generator(title, length=800):
 
     return body
 
-def make_and_write(title, length = 800):
-    composition = generator(title = title, length = length)
+def make_and_write(title, lenth = 800):
+    composition = generator(title = title, lenth = length)
     with open(title + '.txt', 'w+') as f:
         f.write(composition)
         f.close()
